@@ -1,16 +1,18 @@
-#include <iostream>
 #include <fstream>
+#include <iostream>
+
 #include "split.h"
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
 	if (argc < 2) {
-		std::cerr << "usage: " << argv[0] << " <dsv-file> [<link-prefix>]\n";
+		std::cerr << "usage: " << argv[0]
+			  << " <dsv-file> [<link-prefix>]\n";
 		return 1;
 	}
 
 	std::ifstream input(argv[1]);
-	if (! input.is_open()) {
+	if (!input.is_open()) {
 		std::cerr << "couldn't open " << argv[1] << '\n';
 		return 1;
 	}
@@ -18,7 +20,7 @@ int main(int argc, char *argv[])
 	const std::string linkprefix = argc == 3 ? argv[2] : "";
 
 	int lineno = 0;
-	for (std::string line; std::getline(input, line); ) {
+	for (std::string line; std::getline(input, line);) {
 		++lineno;
 		const std::vector<std::string> matches = split(line, "||");
 		if (matches.size() == 5) {
@@ -28,14 +30,18 @@ int main(int argc, char *argv[])
 			const std::string desc = matches[3];
 			const std::string example = matches[4];
 
-			std::cout << "[[" << linkprefix << option << "]] '" << option << "' ";
+			std::cout << "[[" << linkprefix << option << "]] '"
+				  << option << "' ";
 			std::cout << "(parameters: " << syntax << "; ";
-			std::cout << "default value: '" << defaultparam << "')::\n";
+			std::cout << "default value: '" << defaultparam
+				  << "')::\n";
 			std::cout << "         " << desc;
-			std::cout << " (example: " << example <<  ")\n\n";
+			std::cout << " (example: " << example << ")\n\n";
 		} else {
-			std::cerr << "expected exactly 5 cells in " << argv[1] << ":" << lineno;
-			std::cerr << ", but got " << matches.size() << " instead\n";
+			std::cerr << "expected exactly 5 cells in " << argv[1]
+				  << ":" << lineno;
+			std::cerr << ", but got " << matches.size()
+				  << " instead\n";
 			return 1;
 		}
 	}
