@@ -1,7 +1,8 @@
-#include "logger.h"
 #include "FilterParser.h"
+
+#include "logger.h"
 #include "Parser.h"
-#include <utils.h>
+#include "utils.h"
 
 using namespace newsboat;
 
@@ -30,6 +31,7 @@ void FilterParser::add_logop(int op) {
 	expression * expr = new expression(op);
 	if (!root) {
 		printf("error: there can't be a logical expression w/o a prior expression!");
+		delete expr;
 		// TODO: add proper error handling
 	} else {
 		if (curpos != root) {
