@@ -11,14 +11,13 @@
 #include "filtercontainer.h"
 #include "fslock.h"
 #include "regexmanager.h"
+#include "reloader.h"
 #include "remote_api.h"
 #include "rss.h"
 #include "urlreader.h"
 
 namespace newsboat {
 
-extern int ctrl_c_hit;
-
 class view;
 
 class curl_handle;
@@ -32,32 +31,12 @@ public:
 	{
 		return v;
 	}
-	int run(int argc = 0, char* argv[] = nullptr);
-
-	void reload(unsigned int pos,
-		unsigned int max = 0,
-		bool unattended = false,
-		curl_handle* easyhandle = 0);
-
-	void reload_all(bool unattended = false);
-	void reload_indexes(const std::vector<int>& indexes,
-		bool unattended = false);
-	void reload_range(unsigned int start,
-		unsigned int end,
-		unsigned int size,
-		bool unattended = false);
-	void start_reload_all_thread(std::vector<int>* indexes = 0);
+	int run(const CLIArgsParser& args);
 
 	std::vector<std::shared_ptr<rss_item>> search_for_items(
 		const std::string& query,
 		std::shared_ptr<rss_feed> feed);
 
-	void unlock_reload_mutex()
-	{
-		reload_mutex.unlock();
-	}
-	bool trylock_reload_mutex();
-
 	void update_feedlist();
 	void update_visible_feeds();
 	void mark_all_read(unsigned int pos);
@@ -73,7 +52,6 @@ public:
 	}
 	void enqueue_url(const std::string& url,
 		std::shared_ptr<rss_feed> feed);
-	void notify(const std::string& msg);
 
 	void reload_urls_file();
 	void edit_urls_file();
@@ -83,11 +61,6 @@ public:
 		return filters;
 	}
 
-	std::string bookmark(const std::string& url,
-		const std::string& title,
-		const std::string& description,
-		const std::string& feed_title);
-
 	cache* get_cache()
 	{
 		return rsscache;
@@ -108,8 +81,6 @@ public:
 	void write_item(std::shared_ptr<rss_item> item, std::ostream& ostr);
 	std::string write_temporary_item(std::shared_ptr<rss_item> item);
 
-	void mark_deleted(const std::string& guid, bool b);
-
 	void update_config();
 
 	void load_configfile(const std::string& filename);
@@ -118,16 +89,32 @@ public:
 
 	void update_flags(std::shared_ptr<rss_item> item);
 
+	Reloader* get_reloader()
+	{
+		return &reloader;
+	}
+
+	void replace_feed(std::shared_ptr<rss_feed> oldfeed,
+		std::shared_ptr<rss_feed> newfeed,
+		unsigned int pos,
+		bool unattended);
+
+	rss_ignores* get_ignores()
+	{
+		return &ign;
+	}
+
+	remote_api* get_api()
+	{
+		return api;
+	}
+
 private:
-	void print_usage(char* argv0);
-	void print_version_information(const char* argv0, unsigned int level);
 	void import_opml(const std::string& filename);
 	void export_opml();
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
 	int execute_commands(const std::vector<std::string>& cmds);
 
-	std::string prepare_message(unsigned int pos, unsigned int max);
-	void save_feed(std::shared_ptr<rss_feed> feed, unsigned int pos);
 	void enqueue_items(std::shared_ptr<rss_feed> feed);
 
 	std::string generate_enqueue_filename(const std::string& url,
@@ -146,7 +133,6 @@ private:
 	FeedContainer feedcontainer;
 	filtercontainer filters;
 
-	std::mutex reload_mutex;
 	configparser cfgparser;
 	colormanager colorman;
 	regexmanager rxman;
@@ -156,6 +142,8 @@ private:
 	std::unique_ptr<FSLock> fslock;
 
 	ConfigPaths configpaths;
+
+	Reloader reloader;
 };
 
 } // namespace newsboat
