@@ -6,14 +6,15 @@
 namespace newsboat {
 
 class exception : public std::exception {
-	public:
-		explicit exception(unsigned int error_code = 0);
-		~exception() throw() override;
-		const char* what() const throw() override;
-	private:
-		unsigned int ecode;
+public:
+	explicit exception(unsigned int error_code = 0);
+	~exception() throw() override;
+	const char* what() const throw() override;
+
+private:
+	unsigned int ecode;
 };
 
-}
+} // namespace newsboat
 
 #endif /* NEWSBOAT_EXCEPTION_H_ */
