@@ -335,8 +335,13 @@ public:
 		empty = t;
 	}
 
-	void sort(const std::string& method);
-	void sort_unlocked(const std::string& method);
+	bool is_query_feed() const
+	{
+		return rssurl_.substr(0, 6) == "query:";
+	}
+
+	void sort(const ArticleSortStrategy& sort_strategy);
+	void sort_unlocked(const ArticleSortStrategy& sort_strategy);
 
 	void remove_old_deleted_items();
 
@@ -385,6 +390,8 @@ public:
 	void unload();
 	void load();
 
+	void mark_all_items_read();
+
 	std::mutex item_mutex; // this is ugly, but makes it possible to lock
 			       // items use e.g. from the cache class
 private:
