@@ -142,8 +142,10 @@ public:
 	static unsigned long get_auth_method(const std::string& type);
 
 	static bool is_special_url(const std::string& url);
-
 	static bool is_http_url(const std::string& url);
+	static bool is_query_url(const std::string& url);
+	static bool is_filter_url(const std::string& url);
+	static bool is_exec_url(const std::string& url);
 
 	static std::string get_content(xmlNode* node);
 
@@ -163,6 +165,8 @@ public:
 
 	static std::string getcwd();
 
+	static int strnaturalcmp(const std::string& a, const std::string& b);
+
 	static void remove_soft_hyphens(std::string& text);
 
 	static bool is_valid_podcast_type(const std::string& mimetype);
