@@ -459,13 +459,23 @@ void cache::mark_item_deleted(const std::string& guid, bool b)
 	run_sql_nothrow(query);
 }
 
+void cache::mark_feed_items_deleted(const std::string& feedurl)
+{
+	std::lock_guard<std::mutex> lock(mtx);
+	std::string query = prepare_query(
+		"UPDATE rss_item SET deleted = 1 WHERE feedurl = '%s';",
+		feedurl);
+	run_sql_nothrow(query);
+}
+
 // this function writes an rss_feed including all rss_items to the database
 void cache::externalize_rssfeed(std::shared_ptr<rss_feed> feed,
 	bool reset_unread)
 {
 	scope_measure m1("cache::externalize_feed");
-	if (feed->rssurl().substr(0, 6) == "query:")
+	if (feed->is_query_feed()) {
 		return;
+	}
 
 	std::lock_guard<std::mutex> lock(mtx);
 	std::lock_guard<std::mutex> feedlock(feed->item_mutex);
@@ -542,8 +552,9 @@ std::shared_ptr<rss_feed> cache::internalize_rssfeed(std::string rssurl,
 	std::shared_ptr<rss_feed> feed(new rss_feed(this));
 	feed->set_rssurl(rssurl);
 
-	if (rssurl.substr(0, 6) == "query:")
+	if (utils::is_query_url(rssurl)) {
 		return feed;
+	}
 
 	std::lock_guard<std::mutex> lock(mtx);
 	std::lock_guard<std::mutex> feedlock(feed->item_mutex);
@@ -613,14 +624,14 @@ std::shared_ptr<rss_feed> cache::internalize_rssfeed(std::string rssurl,
 		// if some flagged articles were saved, append them
 		feed->add_items(flagged_items);
 	}
-	feed->sort_unlocked(cfg->get_configvalue("article-sort-order"));
+	feed->sort_unlocked(cfg->get_article_sort_strategy());
 	return feed;
 }
 
 std::vector<std::shared_ptr<rss_item>>
 cache::search_for_items(const std::string& querystr, const std::string& feedurl)
 {
-	assert(feedurl.substr(0, 6) != "query:");
+	assert(!utils::is_query_url(feedurl));
 	std::string query;
 	std::vector<std::shared_ptr<rss_item>> items;
 
