@@ -1,6 +1,5 @@
 #include "controller.h"
 
-#include <algorithm>
 #include <cassert>
 #include <cerrno>
 #include <cstdlib>
@@ -18,13 +17,11 @@
 #include <libxml/xmlsave.h>
 #include <libxml/xmlversion.h>
 #include <mutex>
-#include <ncurses.h>
 #include <pwd.h>
 #include <signal.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <sys/utsname.h>
 #include <sys/wait.h>
 #include <unistd.h>
 
@@ -52,18 +49,9 @@
 #include "ttrss_api.h"
 #include "utils.h"
 #include "view.h"
-#include "xlicense.h"
 
 namespace newsboat {
 
-int ctrl_c_hit = 0;
-
-void ctrl_c_action(int /* sig */)
-{
-	LOG(level::DEBUG, "caught SIGINT");
-	ctrl_c_hit = 1;
-}
-
 void sighup_action(int /* sig */)
 {
 	LOG(level::DEBUG, "caught SIGHUP");
@@ -91,6 +79,7 @@ controller::controller()
 	, rsscache(0)
 	, refresh_on_start(false)
 	, api(0)
+	, reloader(this)
 {
 }
 
@@ -109,9 +98,9 @@ void controller::set_view(view* vv)
 	v = vv;
 }
 
-int controller::run(int argc, char* argv[])
+int controller::run(const CLIArgsParser& args)
 {
-	::signal(SIGINT, ctrl_c_action);
+	::signal(SIGINT, view::ctrl_c_action);
 	::signal(SIGPIPE, ignore_signal);
 	::signal(SIGHUP, sighup_action);
 	::signal(SIGCHLD, omg_a_child_died);
@@ -121,8 +110,6 @@ int controller::run(int argc, char* argv[])
 		return EXIT_FAILURE;
 	}
 
-	CLIArgsParser args(argc, argv);
-
 	refresh_on_start = args.refresh_on_start;
 
 	if (args.set_log_file) {
@@ -137,19 +124,10 @@ int controller::run(int argc, char* argv[])
 		std::cerr << args.display_msg << std::endl;
 	}
 
-	if (args.should_print_usage) {
-		print_usage(argv[0]);
-	}
-
 	if (args.should_return) {
 		return args.return_code;
 	}
 
-	if (args.show_version) {
-		print_version_information(argv[0], args.show_version);
-		return EXIT_SUCCESS;
-	}
-
 	configpaths.process_args(args);
 
 	if (args.do_import) {
@@ -286,7 +264,14 @@ int controller::run(int argc, char* argv[])
 		api = new ttrss_api(&cfg);
 		urlcfg = new ttrss_urlreader(configpaths.url_file(), api);
 	} else if (type == "newsblur") {
-		auto cookies = cfg.get_configvalue("cookie-cache");
+		const auto cookies = cfg.get_configvalue("cookie-cache");
+		if (cookies.empty()) {
+			std::cout << strprintf::fmt(
+				_("ERROR: You must set `cookie-cache` to use "
+				  "Newsblur.\n"));
+			return EXIT_FAILURE;
+		}
+
 		std::ofstream check(cookies);
 		if (!check.is_open()) {
 			std::cout << strprintf::fmt(
@@ -368,7 +353,6 @@ int controller::run(int argc, char* argv[])
 			assert(0); // shouldn't happen
 		}
 		std::cout << msg << std::endl << std::endl;
-		print_usage(argv[0]);
 		return EXIT_FAILURE;
 	}
 
@@ -436,7 +420,7 @@ int controller::run(int argc, char* argv[])
 		}
 	}
 
-	feedcontainer.sort_feeds(&cfg);
+	feedcontainer.sort_feeds(cfg.get_feed_sort_strategy());
 
 	if (args.do_export) {
 		export_opml();
@@ -539,26 +523,26 @@ void controller::mark_all_read(const std::string& feedurl)
 		return;
 	}
 
-	std::lock_guard<std::mutex> feedslock(feeds_mutex);
-	for (const auto& feed : feedcontainer.feeds) {
-		std::lock_guard<std::mutex> lock(feed->item_mutex);
-
-		if (feedurl.length() > 0 && feed->rssurl() != feedurl)
-			continue;
-
-		if (feed->total_item_count() > 0) {
-			if (api) {
+	if (feedurl.empty()) { // Mark all feeds as read
+		if (api) {
+			std::lock_guard<std::mutex> feedslock(feeds_mutex);
+			for (const auto& feed : feedcontainer.feeds) {
 				api->mark_all_read(feed->rssurl());
 			}
-			for (const auto& item : feed->items()) {
-				item->set_unread_nowrite(false);
-			}
+		}
+		feedcontainer.mark_all_feeds_read();
+	} else { // Mark a specific feed as read
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
+		const auto feed = feedcontainer.get_feed_by_url(feedurl);
+		if (!feed) {
+			return;
 		}
 
-		// no point in going on - there is only one feed with a given
-		// URL
-		if (feedurl.length() > 0)
-			break;
+		if (api) {
+			api->mark_all_read(feed->rssurl());
+		}
+
+		feed->mark_all_items_read();
 	}
 }
 
@@ -575,7 +559,7 @@ void controller::mark_all_read(unsigned int pos)
 		scope_measure m("controller::mark_all_read");
 		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		const auto feed = feedcontainer.get_feed(pos);
-		if (feed->rssurl().substr(0, 6) == "query:") {
+		if (feed->is_query_feed()) {
 			rsscache->mark_all_read(feed);
 		} else {
 			rsscache->mark_all_read(feed->rssurl());
@@ -591,411 +575,35 @@ void controller::mark_all_read(unsigned int pos)
 	}
 }
 
-void controller::reload(unsigned int pos,
-	unsigned int max,
-	bool unattended,
-	curl_handle* easyhandle)
-{
-	LOG(level::DEBUG, "controller::reload: pos = %u max = %u", pos, max);
-	if (pos < feedcontainer.feeds.size()) {
-		std::shared_ptr<rss_feed> oldfeed = feedcontainer.feeds[pos];
-		std::string errmsg;
-		if (!unattended)
-			v->set_status(strprintf::fmt(_("%sLoading %s..."),
-				prepare_message(pos + 1, max),
-				utils::censor_url(oldfeed->rssurl())));
-
-		bool ignore_dl =
-			(cfg.get_configvalue("ignore-mode") == "download");
-
-		rss_parser parser(oldfeed->rssurl(),
-			rsscache,
-			&cfg,
-			ignore_dl ? &ign : nullptr,
-			api);
-		parser.set_easyhandle(easyhandle);
-		LOG(level::DEBUG, "controller::reload: created parser");
-		try {
-			oldfeed->set_status(dl_status::DURING_DOWNLOAD);
-			std::shared_ptr<rss_feed> newfeed = parser.parse();
-			if (newfeed->total_item_count() > 0) {
-				std::lock_guard<std::mutex> feedslock(
-					feeds_mutex);
-				save_feed(newfeed, pos);
-
-				newfeed->clear_items();
-
-				bool ignore_disp =
-					(cfg.get_configvalue("ignore-mode") ==
-						"display");
-				std::shared_ptr<rss_feed> feed =
-					rsscache->internalize_rssfeed(
-						oldfeed->rssurl(),
-						ignore_disp ? &ign : nullptr);
-				feed->set_tags(
-					urlcfg->get_tags(oldfeed->rssurl()));
-				feed->set_order(oldfeed->get_order());
-				feedcontainer.feeds[pos] = feed;
-				enqueue_items(feed);
-
-				oldfeed->clear_items();
-
-				v->notify_itemlist_change(
-					feedcontainer.feeds[pos]);
-				if (!unattended) {
-					v->set_feedlist(feedcontainer.feeds);
-				}
-			} else {
-				LOG(level::DEBUG,
-					"controller::reload: feed is empty");
-			}
-			oldfeed->set_status(dl_status::SUCCESS);
-			v->set_status("");
-		} catch (const dbexception& e) {
-			errmsg = strprintf::fmt(
-				_("Error while retrieving %s: %s"),
-				utils::censor_url(oldfeed->rssurl()),
-				e.what());
-		} catch (const std::string& emsg) {
-			errmsg = strprintf::fmt(
-				_("Error while retrieving %s: %s"),
-				utils::censor_url(oldfeed->rssurl()),
-				emsg);
-		} catch (rsspp::exception& e) {
-			errmsg = strprintf::fmt(
-				_("Error while retrieving %s: %s"),
-				utils::censor_url(oldfeed->rssurl()),
-				e.what());
-		}
-		if (errmsg != "") {
-			oldfeed->set_status(dl_status::DL_ERROR);
-			v->set_status(errmsg);
-			LOG(level::USERERROR, "%s", errmsg);
-		}
-	} else {
-		v->show_error(_("Error: invalid feed!"));
-	}
-}
-
-void controller::reload_indexes(const std::vector<int>& indexes,
+void controller::replace_feed(std::shared_ptr<rss_feed> oldfeed,
+	std::shared_ptr<rss_feed> newfeed,
+	unsigned int pos,
 	bool unattended)
 {
-	scope_measure m1("controller::reload_indexes");
-	const auto unread_feeds = feedcontainer.unread_feed_count();
-	const auto unread_articles = feedcontainer.unread_item_count();
-	const auto size = feedcontainer.feeds_size();
-
-	for (const auto& idx : indexes) {
-		this->reload(idx, size, unattended);
-	}
-
-	const auto unread_feeds2 = feedcontainer.unread_feed_count();
-	const auto unread_articles2 = feedcontainer.unread_item_count();
-	bool notify_always = cfg.get_configvalue_as_bool("notify-always");
-	if (notify_always || unread_feeds2 != unread_feeds ||
-		unread_articles2 != unread_articles) {
-		fmtstr_formatter fmt;
-		fmt.register_fmt('f', std::to_string(unread_feeds2));
-		fmt.register_fmt('n', std::to_string(unread_articles2));
-		fmt.register_fmt('d',
-			std::to_string(unread_articles2 - unread_articles));
-		fmt.register_fmt(
-			'D', std::to_string(unread_feeds2 - unread_feeds));
-		this->notify(
-			fmt.do_format(cfg.get_configvalue("notify-format")));
-	}
-	if (!unattended)
-		v->set_status("");
-}
-
-void controller::reload_range(unsigned int start,
-	unsigned int end,
-	unsigned int size,
-	bool unattended)
-{
-	std::vector<unsigned int> v;
-	for (unsigned int i = start; i <= end; ++i)
-		v.push_back(i);
-
-	auto extract = [](std::string& s, const std::string& url) {
-		size_t p = url.find("//");
-		p = (p == std::string::npos) ? 0 : p + 2;
-		std::string suff(url.substr(p));
-		p = suff.find('/');
-		s = suff.substr(0, p);
-	};
-
-	std::sort(v.begin(), v.end(), [&](unsigned int a, unsigned int b) {
-		std::string domain1, domain2;
-		extract(domain1, feedcontainer.feeds[a]->rssurl());
-		extract(domain2, feedcontainer.feeds[b]->rssurl());
-		std::reverse(domain1.begin(), domain1.end());
-		std::reverse(domain2.begin(), domain2.end());
-		return domain1 < domain2;
-	});
-
-	curl_handle easyhandle;
-
-	for (const auto& i : v) {
-		LOG(level::DEBUG,
-			"controller::reload_range: reloading feed #%u",
-			i);
-		this->reload(i, size, unattended, &easyhandle);
-	}
-}
-
-void controller::reload_all(bool unattended)
-{
-	const auto unread_feeds = feedcontainer.unread_feed_count();
-	const auto unread_articles = feedcontainer.unread_item_count();
-	unsigned int num_threads = cfg.get_configvalue_as_int("reload-threads");
-	time_t t1, t2, dt;
-
-	feedcontainer.reset_feeds_status();
-	const auto size = feedcontainer.feeds_size();
-
-	if (num_threads < 1) {
-		num_threads = 1;
-	}
-
-	if (num_threads > size) {
-		num_threads = size;
-	}
-
-	t1 = time(nullptr);
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 
+	LOG(level::DEBUG, "controller::replace_feed: feed is nonempty, saving");
+	rsscache->externalize_rssfeed(
+		newfeed, ign.matches_resetunread(newfeed->rssurl()));
 	LOG(level::DEBUG,
-		"controller::reload_all: starting with reload all...");
-	if (num_threads <= 1) {
-		this->reload_range(0, size - 1, size, unattended);
-	} else {
-		std::vector<std::pair<unsigned int, unsigned int>> partitions =
-			utils::partition_indexes(0, size - 1, num_threads);
-		std::vector<std::thread> threads;
-		LOG(level::DEBUG,
-			"controller::reload_all: starting reload threads...");
-		for (unsigned int i = 0; i < num_threads - 1; i++) {
-			threads.push_back(std::thread(reloadrangethread(this,
-				partitions[i].first,
-				partitions[i].second,
-				size,
-				unattended)));
-		}
-		LOG(level::DEBUG,
-			"controller::reload_all: starting my own reload...");
-		this->reload_range(partitions[num_threads - 1].first,
-			partitions[num_threads - 1].second,
-			size,
-			unattended);
-		LOG(level::DEBUG,
-			"controller::reload_all: joining other threads...");
-		for (size_t i = 0; i < threads.size(); i++) {
-			threads[i].join();
-		}
-	}
+		"controller::replace_feed: after externalize_rssfeed");
 
-	// refresh query feeds (update and sort)
-	LOG(level::DEBUG, "controller::reload_all: refresh query feeds");
-	for (const auto& feed : feedcontainer.feeds) {
-		v->prepare_query_feed(feed);
-	}
-	v->force_redraw();
+	bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
+	std::shared_ptr<rss_feed> feed = rsscache->internalize_rssfeed(
+		oldfeed->rssurl(), ignore_disp ? &ign : nullptr);
+	LOG(level::DEBUG,
+		"controller::replace_feed: after internalize_rssfeed");
 
-	feedcontainer.sort_feeds(&cfg);
-	update_feedlist();
+	feed->set_tags(urlcfg->get_tags(oldfeed->rssurl()));
+	feed->set_order(oldfeed->get_order());
+	feedcontainer.feeds[pos] = feed;
+	enqueue_items(feed);
 
-	t2 = time(nullptr);
-	dt = t2 - t1;
-	LOG(level::INFO, "controller::reload_all: reload took %d seconds", dt);
+	oldfeed->clear_items();
 
-	const auto unread_feeds2 = feedcontainer.unread_feed_count();
-	const auto unread_articles2 = feedcontainer.unread_item_count();
-	bool notify_always = cfg.get_configvalue_as_bool("notify-always");
-	if (notify_always || unread_feeds2 > unread_feeds ||
-		unread_articles2 > unread_articles) {
-		int article_count = unread_articles2 - unread_articles;
-		int feed_count = unread_feeds2 - unread_feeds;
-
-		LOG(level::DEBUG, "unread article count: %d", article_count);
-		LOG(level::DEBUG, "unread feed count: %d", feed_count);
-
-		fmtstr_formatter fmt;
-		fmt.register_fmt('f', std::to_string(unread_feeds2));
-		fmt.register_fmt('n', std::to_string(unread_articles2));
-		fmt.register_fmt('d',
-			std::to_string(article_count >= 0 ? article_count : 0));
-		fmt.register_fmt(
-			'D', std::to_string(feed_count >= 0 ? feed_count : 0));
-		this->notify(
-			fmt.do_format(cfg.get_configvalue("notify-format")));
-	}
-}
-
-void controller::notify(const std::string& msg)
-{
-	if (cfg.get_configvalue_as_bool("notify-screen")) {
-		LOG(level::DEBUG, "controller:notify: notifying screen");
-		std::cout << "\033^" << msg << "\033\\";
-		std::cout.flush();
-	}
-	if (cfg.get_configvalue_as_bool("notify-xterm")) {
-		LOG(level::DEBUG, "controller:notify: notifying xterm");
-		std::cout << "\033]2;" << msg << "\033\\";
-		std::cout.flush();
-	}
-	if (cfg.get_configvalue_as_bool("notify-beep")) {
-		LOG(level::DEBUG, "controller:notify: notifying beep");
-		::beep();
-	}
-	if (cfg.get_configvalue("notify-program").length() > 0) {
-		std::string prog = cfg.get_configvalue("notify-program");
-		LOG(level::DEBUG,
-			"controller:notify: notifying external program `%s'",
-			prog);
-		utils::run_command(prog, msg);
-	}
-}
-
-bool controller::trylock_reload_mutex()
-{
-	if (reload_mutex.try_lock()) {
-		LOG(level::DEBUG, "controller::trylock_reload_mutex succeeded");
-		return true;
-	}
-	LOG(level::DEBUG, "controller::trylock_reload_mutex failed");
-	return false;
-}
-
-void controller::start_reload_all_thread(std::vector<int>* indexes)
-{
-	LOG(level::INFO, "starting reload all thread");
-	std::thread t(downloadthread(this, indexes));
-	t.detach();
-}
-
-void controller::print_version_information(const char* argv0,
-	unsigned int level)
-{
-	if (level <= 1) {
-		std::cout << PROGRAM_NAME << " " << PROGRAM_VERSION << " - "
-			  << PROGRAM_URL << std::endl;
-		std::cout << "Copyright (C) 2006-2015 Andreas Krennmair"
-			  << std::endl;
-		std::cout << "Copyright (C) 2015-2018 Alexander Batischev"
-			  << std::endl;
-		std::cout << "Copyright (C) 2006-2017 Newsbeuter contributors"
-			  << std::endl;
-		std::cout << "Copyright (C) 2017-2018 Newsboat contributors"
-			  << std::endl;
-		std::cout << std::endl;
-
-		std::cout << strprintf::fmt(
-				     _("Newsboat is free software licensed "
-				       "under the MIT License. (Type `%s -vv' "
-				       "to see the full text.)"),
-				     argv0)
-			  << std::endl;
-		std::cout << _("It bundles JSON for Modern C++ library, "
-			       "licensed under the MIT License: "
-			       "https://github.com/nlohmann/json")
-			  << std::endl;
-		std::cout << std::endl;
-
-		struct utsname xuts;
-		uname(&xuts);
-		std::cout << PROGRAM_NAME << " " << PROGRAM_VERSION
-			  << std::endl;
-		std::cout << "System: " << xuts.sysname << " " << xuts.release
-			  << " (" << xuts.machine << ")" << std::endl;
-#if defined(__GNUC__) && defined(__VERSION__)
-		std::cout << "Compiler: g++ " << __VERSION__ << std::endl;
-#endif
-		std::cout << "ncurses: " << curses_version()
-			  << " (compiled with " << NCURSES_VERSION << ")"
-			  << std::endl;
-		std::cout << "libcurl: " << curl_version() << " (compiled with "
-			  << LIBCURL_VERSION << ")" << std::endl;
-		std::cout << "SQLite: " << sqlite3_libversion()
-			  << " (compiled with " << SQLITE_VERSION << ")"
-			  << std::endl;
-		std::cout << "libxml2: compiled with " << LIBXML_DOTTED_VERSION
-			  << std::endl
-			  << std::endl;
-	} else {
-		std::cout << LICENSE_str << std::endl;
-	}
-}
-
-void controller::print_usage(char* argv0)
-{
-	auto msg = strprintf::fmt(
-		_("%s %s\nusage: %s [-i <file>|-e] [-u <urlfile>] "
-		  "[-c <cachefile>] [-x <command> ...] [-h]\n"),
-		PROGRAM_NAME,
-		PROGRAM_VERSION,
-		argv0);
-	std::cout << msg;
-
-	struct arg {
-		const char name;
-		const std::string longname;
-		const std::string params;
-		const std::string desc;
-	};
-
-	static const std::vector<arg> args = {
-		{'e', "export-to-opml", "", _s("export OPML feed to stdout")},
-		{'r', "refresh-on-start", "", _s("refresh feeds on start")},
-		{'i', "import-from-opml", _s("<file>"), _s("import OPML file")},
-		{'u',
-			"url-file",
-			_s("<urlfile>"),
-			_s("read RSS feed URLs from <urlfile>")},
-		{'c',
-			"cache-file",
-			_s("<cachefile>"),
-			_s("use <cachefile> as cache file")},
-		{'C',
-			"config-file",
-			_s("<configfile>"),
-			_s("read configuration from <configfile>")},
-		{'X', "vacuum", "", _s("compact the cache")},
-		{'x',
-			"execute",
-			_s("<command>..."),
-			_s("execute list of commands")},
-		{'q', "quiet", "", _s("quiet startup")},
-		{'v', "version", "", _s("get version information")},
-		{'l',
-			"log-level",
-			_s("<loglevel>"),
-			_s("write a log with a certain loglevel (valid values: "
-			   "1 to "
-			   "6)")},
-		{'d',
-			"log-file",
-			_s("<logfile>"),
-			_s("use <logfile> as output log file")},
-		{'E',
-			"export-to-file",
-			_s("<file>"),
-			_s("export list of read articles to <file>")},
-		{'I',
-			"import-from-file",
-			_s("<file>"),
-			_s("import list of read articles from <file>")},
-		{'h', "help", "", _s("this help")}};
-
-	for (const auto& a : args) {
-		std::string longcolumn("-");
-		longcolumn += a.name;
-		longcolumn += ", --" + a.longname;
-		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
-		std::cout << "\t" << longcolumn;
-		for (unsigned int j = 0; j < utils::gentabs(longcolumn); j++) {
-			std::cout << "\t";
-		}
-		std::cout << a.desc << std::endl;
+	v->notify_itemlist_change(feedcontainer.feeds[pos]);
+	if (!unattended) {
+		v->set_feedlist(feedcontainer.feeds);
 	}
 }
 
@@ -1199,7 +807,7 @@ std::vector<std::shared_ptr<rss_item>> controller::search_for_items(
 	std::shared_ptr<rss_feed> feed)
 {
 	std::vector<std::shared_ptr<rss_item>> items;
-	if (feed != nullptr && feed->rssurl().substr(0, 6) == "query:") {
+	if (feed && feed->is_query_feed()) {
 		std::unordered_set<std::string> guids;
 		for (const auto& item : feed->items()) {
 			if (!item->deleted()) {
@@ -1260,17 +868,12 @@ void controller::reload_urls_file()
 	unsigned int i = 0;
 
 	for (const auto& url : urlcfg->get_urls()) {
-		bool found = false;
-		for (const auto& feed : feedcontainer.feeds) {
-			if (url == feed->rssurl()) {
-				found = true;
-				feed->set_tags(urlcfg->get_tags(url));
-				feed->set_order(i);
-				new_feeds.push_back(feed);
-				break;
-			}
-		}
-		if (!found) {
+		const auto feed = feedcontainer.get_feed_by_url(url);
+		if (feed) {
+			feed->set_tags(urlcfg->get_tags(url));
+			feed->set_order(i);
+			new_feeds.push_back(feed);
+		} else {
 			try {
 				bool ignore_disp =
 					(cfg.get_configvalue("ignore-mode") ==
@@ -1295,7 +898,7 @@ void controller::reload_urls_file()
 	v->set_tags(urlcfg->get_alltags());
 
 	feedcontainer.set_feeds(new_feeds);
-	feedcontainer.sort_feeds(&cfg);
+	feedcontainer.sort_feeds(cfg.get_feed_sort_strategy());
 	update_feedlist();
 }
 
@@ -1323,58 +926,6 @@ void controller::edit_urls_file()
 	reload_urls_file();
 }
 
-/* When passing an argument to a shell script, empty string should be
- * represented as '' (two quote marks), otherwise shell won't be able to tell
- * that the parameter is empty */
-std::string quote_empty(const std::string& input)
-{
-	if (input.empty()) {
-		return "''";
-	} else {
-		return input;
-	}
-}
-
-std::string controller::bookmark(const std::string& url,
-	const std::string& title,
-	const std::string& description,
-	const std::string& feed_title)
-{
-	std::string bookmark_cmd = cfg.get_configvalue("bookmark-cmd");
-	bool is_interactive =
-		cfg.get_configvalue_as_bool("bookmark-interactive");
-	if (bookmark_cmd.length() > 0) {
-		std::string cmdline = strprintf::fmt("%s '%s' '%s' '%s' '%s'",
-			bookmark_cmd,
-			utils::replace_all(url, "'", "%27"),
-			utils::replace_all(title, "'", "%27"),
-			utils::replace_all(description, "'", "%27"),
-			utils::replace_all(feed_title, "'", "%27"));
-
-		LOG(level::DEBUG, "controller::bookmark: cmd = %s", cmdline);
-
-		if (is_interactive) {
-			v->push_empty_formaction();
-			stfl::reset();
-			utils::run_interactively(
-				cmdline, "controller::bookmark");
-			v->pop_current_formaction();
-			return "";
-		} else {
-			char* my_argv[4];
-			my_argv[0] = const_cast<char*>("/bin/sh");
-			my_argv[1] = const_cast<char*>("-c");
-			my_argv[2] = const_cast<char*>(cmdline.c_str());
-			my_argv[3] = nullptr;
-			return utils::run_program(my_argv, "");
-		}
-	} else {
-		return _(
-			"bookmarking support is not configured. Please set the "
-			"configuration variable `bookmark-cmd' accordingly.");
-	}
-}
-
 int controller::execute_commands(const std::vector<std::string>& cmds)
 {
 	if (v->formaction_stack_size() > 0)
@@ -1384,7 +935,7 @@ int controller::execute_commands(const std::vector<std::string>& cmds)
 			"controller::execute_commands: executing `%s'",
 			cmd);
 		if (cmd == "reload") {
-			reload_all(true);
+			reloader.reload_all(true);
 		} else if (cmd == "print-unread") {
 			std::cout << strprintf::fmt(_("%u unread articles"),
 					     rsscache->get_unread_count())
@@ -1404,7 +955,12 @@ int controller::execute_commands(const std::vector<std::string>& cmds)
 std::string controller::write_temporary_item(std::shared_ptr<rss_item> item)
 {
 	char filename[_POSIX_PATH_MAX];
-	snprintf(filename, sizeof(filename), "/tmp/newsboat-article.XXXXXX");
+	char *tmpdir = getenv("TMPDIR");
+	if (tmpdir != nullptr) {
+	  snprintf(filename, sizeof(filename), "%s/newsboat-article.XXXXXX", tmpdir);
+	} else {
+	  snprintf(filename, sizeof(filename), "/tmp/newsboat-article.XXXXXX");
+	}
 	int fd = mkstemp(filename);
 	if (fd != -1) {
 		write_item(item, filename);
@@ -1420,8 +976,9 @@ void controller::write_item(std::shared_ptr<rss_item> item,
 {
 	std::fstream f;
 	f.open(filename.c_str(), std::fstream::out);
-	if (!f.is_open())
+	if (!f.is_open()) {
 		throw exception(errno);
+	}
 
 	write_item(item, f);
 }
@@ -1466,52 +1023,6 @@ void controller::write_item(std::shared_ptr<rss_item> item, std::ostream& ostr)
 	ostr << txtfmt.format_text_plain(width) << std::endl;
 }
 
-void controller::mark_deleted(const std::string& guid, bool b)
-{
-	rsscache->mark_item_deleted(guid, b);
-}
-
-std::string controller::prepare_message(unsigned int pos, unsigned int max)
-{
-	if (max > 0) {
-		return strprintf::fmt("(%u/%u) ", pos, max);
-	}
-	return "";
-}
-
-void controller::save_feed(std::shared_ptr<rss_feed> feed, unsigned int pos)
-{
-	if (!feed->is_empty()) {
-		LOG(level::DEBUG,
-			"controller::save_feed: feed is nonempty, saving");
-		rsscache->externalize_rssfeed(
-			feed, ign.matches_resetunread(feed->rssurl()));
-		LOG(level::DEBUG,
-			"controller::save_feed: after externalize_rssfeed");
-
-		bool ignore_disp =
-			(cfg.get_configvalue("ignore-mode") == "display");
-		feed = rsscache->internalize_rssfeed(
-			feed->rssurl(), ignore_disp ? &ign : nullptr);
-		LOG(level::DEBUG,
-			"controller::save_feed: after internalize_rssfeed");
-		feed->set_tags(urlcfg->get_tags(feed->rssurl()));
-		{
-			unsigned int order =
-				feedcontainer.feeds[pos]->get_order();
-			std::lock_guard<std::mutex> itemlock(
-				feedcontainer.feeds[pos]->item_mutex);
-			feedcontainer.feeds[pos]->clear_items();
-			feed->set_order(order);
-		}
-		feedcontainer.feeds[pos] = feed;
-		v->notify_itemlist_change(feedcontainer.feeds[pos]);
-	} else {
-		LOG(level::DEBUG,
-			"controller::save_feed: feed is empty, not saving");
-	}
-}
-
 void controller::enqueue_items(std::shared_ptr<rss_feed> feed)
 {
 	if (!cfg.get_configvalue_as_bool("podcast-auto-enqueue"))
