@@ -4,11 +4,12 @@
 
 namespace newsboat {
 
-downloadthread::downloadthread(controller* c, std::vector<int>* idxs)
-	: ctrl(c)
+downloadthread::downloadthread(Reloader& r, std::vector<int>* idxs)
+	: reloader(r)
 {
-	if (idxs)
+	if (idxs) {
 		indexes = *idxs;
+	}
 }
 
 downloadthread::~downloadthread() {}
@@ -23,32 +24,14 @@ void downloadthread::operator()()
 	LOG(level::DEBUG,
 		"downloadthread::run: inside downloadthread, reloading all "
 		"feeds...");
-	if (ctrl->trylock_reload_mutex()) {
+	if (reloader.trylock_reload_mutex()) {
 		if (indexes.size() == 0) {
-			ctrl->reload_all();
+			reloader.reload_all();
 		} else {
-			ctrl->reload_indexes(indexes);
+			reloader.reload_indexes(indexes);
 		}
-		ctrl->unlock_reload_mutex();
+		reloader.unlock_reload_mutex();
 	}
 }
 
-reloadrangethread::reloadrangethread(controller* c,
-	unsigned int start,
-	unsigned int end,
-	unsigned int size,
-	bool unattended)
-	: ctrl(c)
-	, s(start)
-	, e(end)
-	, ss(size)
-	, u(unattended)
-{
-}
-
-void reloadrangethread::operator()()
-{
-	ctrl->reload_range(s, e, ss, u);
-}
-
 } // namespace newsboat
