@@ -2,27 +2,25 @@
 
 #include <algorithm> // stable_sort
 #include <numeric>   // accumulate
-#include <strings.h> // strcasecmp
+
+#include "utils.h"
 
 namespace newsboat {
 
-void FeedContainer::sort_feeds(configcontainer* cfg)
+void FeedContainer::sort_feeds(const FeedSortStrategy& sort_strategy)
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
-	const auto sortmethod_info =
-		utils::tokenize(cfg->get_configvalue("feed-sort-order"), "-");
-	std::string sortmethod = sortmethod_info[0];
-	std::string direction = "desc";
-	if (sortmethod_info.size() > 1)
-		direction = sortmethod_info[1];
-	if (sortmethod == "none") {
+
+	switch (sort_strategy.sm) {
+	case feed_sort_method_t::NONE:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
 				std::shared_ptr<rss_feed> b) {
 				return a->get_order() < b->get_order();
 			});
-	} else if (sortmethod == "firsttag") {
+		break;
+	case feed_sort_method_t::FIRST_TAG:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
@@ -32,18 +30,20 @@ void FeedContainer::sort_feeds(configcontainer* cfg)
 					return a->get_firsttag().length() >
 						b->get_firsttag().length();
 				}
-				return strcasecmp(a->get_firsttag().c_str(),
+				return utils::strnaturalcmp(a->get_firsttag().c_str(),
 					       b->get_firsttag().c_str()) < 0;
 			});
-	} else if (sortmethod == "title") {
+		break;
+	case feed_sort_method_t::TITLE:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
 				std::shared_ptr<rss_feed> b) {
-				return strcasecmp(a->title().c_str(),
+				return utils::strnaturalcmp(a->title().c_str(),
 					       b->title().c_str()) < 0;
 			});
-	} else if (sortmethod == "articlecount") {
+		break;
+	case feed_sort_method_t::ARTICLE_COUNT:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
@@ -51,7 +51,8 @@ void FeedContainer::sort_feeds(configcontainer* cfg)
 				return a->total_item_count() <
 					b->total_item_count();
 			});
-	} else if (sortmethod == "unreadarticlecount") {
+		break;
+	case feed_sort_method_t::UNREAD_ARTICLE_COUNT:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
@@ -59,7 +60,8 @@ void FeedContainer::sort_feeds(configcontainer* cfg)
 				return a->unread_item_count() <
 					b->unread_item_count();
 			});
-	} else if (sortmethod == "lastupdated") {
+		break;
+	case feed_sort_method_t::LAST_UPDATED:
 		std::stable_sort(feeds.begin(),
 			feeds.end(),
 			[](std::shared_ptr<rss_feed> a,
@@ -84,9 +86,15 @@ void FeedContainer::sort_feeds(configcontainer* cfg)
 						cmp);
 				return cmp(a_item, b_item);
 			});
+		break;
 	}
-	if (direction == "asc") {
+
+	switch (sort_strategy.sd) {
+	case sort_direction_t::ASC:
 		std::reverse(feeds.begin(), feeds.end());
+		break;
+	case sort_direction_t::DESC:
+		break;
 	}
 }
 
@@ -116,6 +124,14 @@ void FeedContainer::mark_all_feed_items_read(const unsigned int feed_pos)
 	}
 }
 
+void FeedContainer::mark_all_feeds_read()
+{
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
+	for (const auto& feed : feeds) {
+		feed->mark_all_items_read();
+	}
+}
+
 void FeedContainer::add_feed(const std::shared_ptr<rss_feed> feed)
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
@@ -126,7 +142,7 @@ void FeedContainer::populate_query_feeds()
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	for (const auto& feed : feeds) {
-		if (feed->rssurl().substr(0, 6) == "query:") {
+		if (feed->is_query_feed()) {
 			feed->update_items(feeds);
 		}
 	}
