@@ -29,7 +29,7 @@ itemlist_formaction::itemlist_formaction(view* vv, std::string formstr)
 	, rxman(0)
 	, old_width(0)
 	, old_itempos(-1)
-	, old_sort_order("")
+	, old_sort_strategy({art_sort_method_t::TITLE, sort_direction_t::DESC})
 	, invalidated(false)
 	, invalidation_mode(InvalidationMode::COMPLETE)
 {
@@ -82,7 +82,7 @@ void itemlist_formaction::process_operation(operation op,
 			// mark as deleted
 			visible_items[itempos].first->set_deleted(
 				!visible_items[itempos].first->deleted());
-			v->get_ctrl()->mark_deleted(
+			v->get_ctrl()->get_cache()->mark_item_deleted(
 				visible_items[itempos].first->guid(),
 				visible_items[itempos].first->deleted());
 			if (itempos < visible_items.size() - 1)
@@ -94,6 +94,18 @@ void itemlist_formaction::process_operation(operation op,
 				_("No item selected!")); // should not happen
 		}
 	} break;
+	case OP_DELETE_ALL: {
+		scope_measure m1("OP_DELETE_ALL");
+		if (visible_items.size() > 0) {
+			v->get_ctrl()->mark_all_read(pos);
+			for (const auto& pair : visible_items) {
+				pair.first->set_deleted(true);
+			}
+			v->get_ctrl()->get_cache()->mark_feed_items_deleted(
+				feed->rssurl());
+			invalidate(InvalidationMode::COMPLETE);
+		}
+	} break;
 	case OP_PURGE_DELETED: {
 		scope_measure m1("OP_PURGE_DELETED");
 		feed->purge_deleted_items();
@@ -194,10 +206,12 @@ void itemlist_formaction::process_operation(operation op,
 					// mark as undeleted
 					visible_items[itempos]
 						.first->set_deleted(false);
-					v->get_ctrl()->mark_deleted(
-						visible_items[itempos]
-							.first->guid(),
-						false);
+					v->get_ctrl()
+						->get_cache()
+						->mark_item_deleted(
+							visible_items[itempos]
+								.first->guid(),
+							false);
 					// toggle read
 					bool unread = visible_items[itempos]
 							      .first->unread();
@@ -357,7 +371,7 @@ void itemlist_formaction::process_operation(operation op,
 		if (!show_searchresult) {
 			LOG(level::INFO,
 				"itemlist_formaction: reloading current feed");
-			v->get_ctrl()->reload(pos);
+			v->get_ctrl()->get_reloader()->reload(pos);
 			invalidate(InvalidationMode::COMPLETE);
 		} else {
 			v->show_error(
@@ -852,11 +866,10 @@ void itemlist_formaction::prepare()
 {
 	std::lock_guard<std::mutex> mtx(redraw_mtx);
 
-	std::string sort_order =
-		v->get_cfg()->get_configvalue("article-sort-order");
-	if (sort_order != old_sort_order) {
-		feed->sort(sort_order);
-		old_sort_order = sort_order;
+	const auto sort_strategy = v->get_cfg()->get_article_sort_strategy();
+	if (sort_strategy != old_sort_strategy) {
+		feed->sort(sort_strategy);
+		old_sort_strategy = sort_strategy;
 		invalidate(InvalidationMode::COMPLETE);
 	}
 
@@ -1352,11 +1365,11 @@ std::string itemlist_formaction::title()
 	if (feed->rssurl() == "") {
 		return strprintf::fmt(_("Search Result - '%s'"), searchphrase);
 	} else {
-		if (feed->rssurl().substr(0, 6) == "query:")
+		if (feed->is_query_feed()) {
 			return strprintf::fmt(_("Query Feed - %s"),
 				feed->rssurl().substr(
 					6, feed->rssurl().length() - 6));
-		else {
+		} else {
 			auto feedtitle = feed->title();
 			utils::remove_soft_hyphens(feedtitle);
 			return strprintf::fmt(
