@@ -230,6 +230,11 @@ static op_desc opdescs[] = {
 		"D",
 		_("Delete article"),
 		KM_ARTICLELIST | KM_ARTICLE},
+	{OP_DELETE_ALL,
+		"delete-all-articles",
+		"^D",
+		_("Delete all articles"),
+		KM_ARTICLELIST},
 	{OP_PURGE_DELETED,
 		"purge-deleted",
 		"$",
