@@ -1,13 +1,18 @@
-#include <list_formaction.h>
-#include <view.h>
+#include "list_formaction.h"
+
+#include "view.h"
 
 namespace newsboat {
 
-list_formaction::list_formaction(view * v, std::string formstr)
-:formaction(v, formstr)
-{}
+list_formaction::list_formaction(view* v, std::string formstr)
+	: formaction(v, formstr)
+{
+}
 
-void list_formaction::process_operation(operation op, bool, std::vector<std::string> *) {
+void list_formaction::process_operation(operation op,
+	bool,
+	std::vector<std::string>*)
+{
 	switch (op) {
 	case OP_1:
 		formaction::start_cmdline("1");
@@ -41,10 +46,14 @@ void list_formaction::process_operation(operation op, bool, std::vector<std::str
 	}
 }
 
-void list_formaction::open_unread_items_in_browser(std::shared_ptr<rss_feed> feed , bool markread){
+void list_formaction::open_unread_items_in_browser(
+	std::shared_ptr<rss_feed> feed,
+	bool markread)
+{
 	int tabcount = 0;
-	for (auto item : feed->items()) {
-		if (tabcount < v->get_cfg()->get_configvalue_as_int("max-browser-tabs")) {
+	for (const auto& item : feed->items()) {
+		if (tabcount < v->get_cfg()->get_configvalue_as_int(
+				       "max-browser-tabs")) {
 			if (item->unread()) {
 				v->open_in_browser(item->link());
 				tabcount += 1;
@@ -56,4 +65,4 @@ void list_formaction::open_unread_items_in_browser(std::shared_ptr<rss_feed> fee
 	}
 }
 
-}
+} // namespace newsboat
