@@ -1,6 +1,7 @@
 #include "ocnews_api.h"
 
 #include "logger.h"
+#include "utils.h"
 
 namespace newsboat {
 
@@ -28,7 +29,7 @@ void ocnews_urlreader::reload()
 
 	std::vector<std::string>& file_urls(ur.get_urls());
 	for (const auto& url : file_urls) {
-		if (url.substr(0, 6) == "query:") {
+		if (utils::is_query_url(url)) {
 			urls.push_back(url);
 		}
 	}
