@@ -9,6 +9,7 @@
 #include <langinfo.h>
 #include <sstream>
 #include <sys/utsname.h>
+#include <string.h>
 #include <time.h>
 
 #include "cache.h"
@@ -156,28 +157,24 @@ std::string rss_item::pubDate() const
 unsigned int rss_feed::unread_item_count()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
-	unsigned int count = 0;
-	for (const auto& item : items_) {
-		if (item->unread())
-			++count;
-	}
-	return count;
+	return std::count_if(items_.begin(),
+		items_.end(),
+		[](const std::shared_ptr<rss_item>& item) {
+			return item->unread();
+		});
 }
 
 bool rss_feed::matches_tag(const std::string& tag)
 {
-	for (const auto& t : tags_) {
-		if (tag == t)
-			return true;
-	}
-	return false;
+	return std::find_if(
+		       tags_.begin(), tags_.end(), [&](const std::string& t) {
+			       return tag == t;
+		       }) != tags_.end();
 }
 
 std::string rss_feed::get_firsttag()
 {
-	if (tags_.size() == 0)
-		return "";
-	return tags_[0];
+	return tags_.empty() ? "" : tags_.front();
 }
 
 std::string rss_feed::get_tags()
@@ -194,10 +191,7 @@ std::string rss_feed::get_tags()
 
 void rss_feed::set_tags(const std::vector<std::string>& tags)
 {
-	tags_.clear();
-	for (const auto& tag : tags) {
-		tags_.push_back(tag);
-	}
+	tags_ = tags;
 }
 
 void rss_item::set_enclosure_url(const std::string& url)
@@ -252,12 +246,9 @@ std::string rss_feed::description() const
 
 bool rss_feed::hidden() const
 {
-	for (const auto& tag : tags_) {
-		if (tag.substr(0, 1) == "!") {
-			return true;
-		}
-	}
-	return false;
+	return std::any_of(tags_.begin(),
+		tags_.end(),
+		[](const std::string& tag) { return tag.substr(0, 1) == "!"; });
 }
 
 std::shared_ptr<rss_item> rss_feed::get_item_by_guid(const std::string& guid)
@@ -355,23 +346,14 @@ void rss_item::sort_flags()
 {
 	std::sort(flags_.begin(), flags_.end());
 
-	auto it = flags_.begin();
-	while (it != flags_.end()) {
-		if (!isalpha(*it)) {
-			flags_.erase(it);
-		} else {
-			it += 1;
-		}
-	}
+	// Erase non-alpha characters
+	flags_.erase(std::remove_if(flags_.begin(),
+			     flags_.end(),
+			     [](const char c) { return !isalpha(c); }),
+		flags_.end());
 
-	for (unsigned int i = 0; i < flags_.size(); ++i) {
-		if (i < (flags_.size() - 1)) {
-			if (flags_[i] == flags_[i + 1]) {
-				flags_.erase(i + 1, 1);
-				--i;
-			}
-		}
-	}
+	// Erase doubled characters
+	flags_.erase(std::unique(flags_.begin(), flags_.end()), flags_.end());
 }
 
 bool rss_feed::has_attribute(const std::string& attribname)
@@ -490,20 +472,18 @@ bool rss_ignores::matches(rss_item* item)
 
 bool rss_ignores::matches_lastmodified(const std::string& url)
 {
-	for (const auto& ignore_url : ignores_lastmodified) {
-		if (url == ignore_url)
-			return true;
-	}
-	return false;
+	return std::find_if(ignores_lastmodified.begin(),
+		       ignores_lastmodified.end(),
+		       [&](const std::string& u) { return u == url; }) !=
+		ignores_lastmodified.end();
 }
 
 bool rss_ignores::matches_resetunread(const std::string& url)
 {
-	for (const auto& rf : resetflag) {
-		if (url == rf)
-			return true;
-	}
-	return false;
+	return std::find_if(resetflag.begin(),
+		       resetflag.end(),
+		       [&](const std::string& u) { return u == url; }) !=
+		resetflag.end();
 }
 
 void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
@@ -523,8 +503,7 @@ void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
 	items_guid_map.clear();
 
 	for (const auto& feed : feeds) {
-		if (feed->rssurl().substr(0, 6) !=
-			"query:") { // don't fetch items from other query feeds!
+		if (!feed->is_query_feed()) { // don't fetch items from other query feeds!
 			for (const auto& item : feed->items()) {
 				if (m.matches(item.get())) {
 					LOG(level::DEBUG,
@@ -563,7 +542,7 @@ void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
 void rss_feed::set_rssurl(const std::string& u)
 {
 	rssurl_ = u;
-	if (rssurl_.substr(0, 6) == "query:") {
+	if (utils::is_query_url(u)) {
 		/* Query string looks like this:
 		 *
 		 * query:Title:unread = "yes" and age between 0:7
@@ -602,110 +581,93 @@ void rss_feed::set_rssurl(const std::string& u)
 	}
 }
 
-void rss_feed::sort(const std::string& method)
+void rss_feed::sort(const ArticleSortStrategy& sort_strategy)
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
-	sort_unlocked(method);
+	sort_unlocked(sort_strategy);
 }
 
-void rss_feed::sort_unlocked(const std::string& method)
+void rss_feed::sort_unlocked(const ArticleSortStrategy& sort_strategy)
 {
-	std::vector<std::string> methods = utils::tokenize(method, "-");
-	bool reverse = false;
-
-	if (!methods.empty() &&
-		methods[0] == "date") { // date is descending by default
-		if (methods.size() > 1 && methods[1] == "asc") {
-			reverse = true;
-		}
-	} else { // all other sort methods are ascending by default
-		if (methods.size() > 1 && methods[1] == "desc") {
-			reverse = true;
-		}
-	}
-
-	if (!methods.empty()) {
-		if (methods[0] == "title") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (strcasecmp(
-							   a->title().c_str(),
-							   b->title().c_str()) >
-							  0)
-						: (strcasecmp(
-							   a->title().c_str(),
-							   b->title().c_str()) <
-							  0);
-				});
-		} else if (methods[0] == "flags") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (strcmp(a->flags().c_str(),
-							   b->flags().c_str()) >
-							  0)
-						: (strcmp(a->flags().c_str(),
-							   b->flags().c_str()) <
-							  0);
-				});
-		} else if (methods[0] == "author") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (strcmp(a->author().c_str(),
-							   b->author()
-								   .c_str()) >
-							  0)
-						: (strcmp(a->author().c_str(),
-							   b->author()
-								   .c_str()) <
-							  0);
-				});
-		} else if (methods[0] == "link") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (strcmp(a->link().c_str(),
-							   b->link().c_str()) >
-							  0)
-						: (strcmp(a->link().c_str(),
-							   b->link().c_str()) <
-							  0);
-				});
-		} else if (methods[0] == "guid") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (strcmp(a->guid().c_str(),
-							   b->guid().c_str()) >
-							  0)
-						: (strcmp(a->guid().c_str(),
-							   b->guid().c_str()) <
-							  0);
-				});
-		} else if (methods[0] == "date") {
-			std::stable_sort(items_.begin(),
-				items_.end(),
-				[&](std::shared_ptr<rss_item> a,
-					std::shared_ptr<rss_item> b) {
-					return reverse
-						? (a->pubDate_timestamp() >
-							  b->pubDate_timestamp())
-						: (a->pubDate_timestamp() <
-							  b->pubDate_timestamp());
-				});
-		}
+	switch (sort_strategy.sm) {
+	case art_sort_method_t::TITLE:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				return sort_strategy.sd ==
+						sort_direction_t::DESC
+					? (utils::strnaturalcmp(a->title().c_str(),
+						   b->title().c_str()) > 0)
+					: (utils::strnaturalcmp(a->title().c_str(),
+						   b->title().c_str()) < 0);
+			});
+		break;
+	case art_sort_method_t::FLAGS:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				return sort_strategy.sd ==
+						sort_direction_t::DESC
+					? (strcmp(a->flags().c_str(),
+						   b->flags().c_str()) > 0)
+					: (strcmp(a->flags().c_str(),
+						   b->flags().c_str()) < 0);
+			});
+		break;
+	case art_sort_method_t::AUTHOR:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				return sort_strategy.sd ==
+						sort_direction_t::DESC
+					? (strcmp(a->author().c_str(),
+						   b->author().c_str()) > 0)
+					: (strcmp(a->author().c_str(),
+						   b->author().c_str()) < 0);
+			});
+		break;
+	case art_sort_method_t::LINK:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				return sort_strategy.sd ==
+						sort_direction_t::DESC
+					? (strcmp(a->link().c_str(),
+						   b->link().c_str()) > 0)
+					: (strcmp(a->link().c_str(),
+						   b->link().c_str()) < 0);
+			});
+		break;
+	case art_sort_method_t::GUID:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				return sort_strategy.sd ==
+						sort_direction_t::DESC
+					? (strcmp(a->guid().c_str(),
+						   b->guid().c_str()) > 0)
+					: (strcmp(a->guid().c_str(),
+						   b->guid().c_str()) < 0);
+			});
+		break;
+	case art_sort_method_t::DATE:
+		std::stable_sort(items_.begin(),
+			items_.end(),
+			[&](std::shared_ptr<rss_item> a,
+				std::shared_ptr<rss_item> b) {
+				// date is descending by default
+				return sort_strategy.sd == sort_direction_t::ASC
+					? (a->pubDate_timestamp() >
+						  b->pubDate_timestamp())
+					: (a->pubDate_timestamp() <
+						  b->pubDate_timestamp());
+			});
+		break;
 	}
 }
 
@@ -723,21 +685,23 @@ void rss_feed::purge_deleted_items()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	scope_measure m1("rss_feed::purge_deleted_items");
-	auto it = items_.begin();
-	while (it != items_.end()) {
-		if ((*it)->deleted()) {
-			{
-				std::lock_guard<std::mutex> lock2(
-					items_guid_map_mutex);
-				items_guid_map.erase((*it)->guid());
+
+	// Purge in items_guid_map
+	{
+		std::lock_guard<std::mutex> lock2(items_guid_map_mutex);
+		for (const auto& item : items_) {
+			if (item->deleted()) {
+				items_guid_map.erase(item->guid());
 			}
-			items_.erase(it);
-			it = items_.begin(); // items_ modified -> iterator
-					     // invalidated
-		} else {
-			++it;
 		}
 	}
+
+	items_.erase(std::remove_if(items_.begin(),
+			     items_.end(),
+			     [](const std::shared_ptr<rss_item> item) {
+				     return item->deleted();
+			     }),
+		items_.end());
 }
 
 void rss_feed::set_feedptrs(std::shared_ptr<rss_feed> self)
@@ -782,4 +746,12 @@ void rss_feed::load()
 	ch->fetch_descriptions(this);
 }
 
+void rss_feed::mark_all_items_read()
+{
+	std::lock_guard<std::mutex> lock(item_mutex);
+	for (const auto& item : items_) {
+		item->set_unread_nowrite(false);
+	}
+}
+
 } // namespace newsboat
