@@ -26,6 +26,7 @@
 #include <unistd.h>
 #include <unordered_set>
 
+#include "3rd-party/alphanum.hpp"
 #include "config.h"
 #include "logger.h"
 #include "strprintf.h"
@@ -971,8 +972,7 @@ std::string utils::join(const std::vector<std::string>& strings,
 
 bool utils::is_special_url(const std::string& url)
 {
-	return url.substr(0, 6) == "query:" || url.substr(0, 7) == "filter:" ||
-		url.substr(0, 5) == "exec:";
+	return is_query_url(url) || is_filter_url(url) || is_exec_url(url);
 }
 
 bool utils::is_http_url(const std::string& url)
@@ -980,10 +980,25 @@ bool utils::is_http_url(const std::string& url)
 	return url.substr(0, 7) == "http://" || url.substr(0, 8) == "https://";
 }
 
+bool utils::is_query_url(const std::string& url)
+{
+	return url.substr(0, 6) == "query:";
+}
+
+bool utils::is_filter_url(const std::string& url)
+{
+	return url.substr(0, 7) == "filter:";
+}
+
+bool utils::is_exec_url(const std::string& url)
+{
+	return url.substr(0, 5) == "exec:";
+}
+
 std::string utils::censor_url(const std::string& url)
 {
-	std::string rv;
-	if (url.length() > 0 && !utils::is_special_url(url)) {
+	std::string rv(url);
+	if (!url.empty() && !utils::is_special_url(url)) {
 		const char* myuri = url.c_str();
 		xmlURIPtr uri = xmlParseURI(myuri);
 		if (uri) {
@@ -997,10 +1012,7 @@ std::string utils::censor_url(const std::string& url)
 			rv = (const char*)uristr;
 			xmlFree(uristr);
 			xmlFreeURI(uri);
-		} else
-			return url;
-	} else {
-		rv = url;
+		}
 	}
 	return rv;
 }
@@ -1264,6 +1276,10 @@ int utils::mkdir_parents(const std::string& p, mode_t mode)
 	/* Have to copy the path because we're going to modify it */
 	const size_t length = p.length() + 1;
 	char* pathname = (char*)malloc(length);
+	if (pathname == nullptr) {
+		// errno is already set by malloc(), so simply return with an error
+		return -1;
+	}
 	strncpy(pathname, p.c_str(), length);
 	/* This pointer will run through the whole string looking for '/'.
 	 * We move it by one if path starts with slash because if we don't, the
@@ -1370,6 +1386,11 @@ std::string utils::getcwd()
 	return std::string(result.data());
 }
 
+int utils::strnaturalcmp(const std::string& a, const std::string& b)
+{
+	return doj::alphanum_comp(a, b);
+}
+
 void utils::remove_soft_hyphens(std::string& text)
 {
 	/* Remove all soft-hyphens as they can behave unpredictably (see
