@@ -52,6 +52,10 @@ extern "C" {
 #include "urlview_formaction.h"
 #include "utils.h"
 
+namespace {
+bool ctrl_c_hit = false;
+}
+
 namespace newsboat {
 
 view::view(controller* c)
@@ -215,7 +219,7 @@ int view::run()
 			const char* event = fa->get_form()->run(60000);
 
 			if (ctrl_c_hit) {
-				ctrl_c_hit = 0;
+				ctrl_c_hit = false;
 				cancel_input(fa);
 				if (!get_cfg()->get_configvalue_as_bool(
 					    "confirm-exit") ||
@@ -437,7 +441,7 @@ void view::set_feedlist(std::vector<std::shared_ptr<rss_feed>> feeds)
 		std::lock_guard<std::mutex> lock(mtx);
 
 		for (const auto& feed : feeds) {
-			if (feed->rssurl().substr(0, 6) != "query:") {
+			if (!feed->is_query_feed()) {
 				feed->set_feedptrs(feed);
 			}
 		}
@@ -971,14 +975,14 @@ bool view::get_prev_feed(itemlist_formaction* itemlist)
 
 void view::prepare_query_feed(std::shared_ptr<rss_feed> feed)
 {
-	if (feed->rssurl().substr(0, 6) == "query:") {
+	if (feed->is_query_feed()) {
 		LOG(level::DEBUG,
 			"view::prepare_query_feed: %s",
 			feed->rssurl());
 
 		set_status(_("Updating query feed..."));
 		feed->update_items(ctrl->get_feedcontainer()->get_all_feeds());
-		feed->sort(cfg->get_configvalue("article-sort-order"));
+		feed->sort(cfg->get_article_sort_strategy());
 		notify_itemlist_change(feed);
 		set_status("");
 	}
@@ -1311,4 +1315,10 @@ void view::dump_current_form()
 	set_status(strprintf::fmt("Dumped current form to file %s", fnbuf));
 }
 
+void view::ctrl_c_action(int /* sig */)
+{
+	LOG(level::DEBUG, "caught SIGINT");
+	ctrl_c_hit = true;
+}
+
 } // namespace newsboat
